@@ -108,7 +108,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
 
     def add_tags(
-        self, *, LoadBalancerNames: Sequence[str], Tags: Sequence["TagTypeDef"]
+        self, *, LoadBalancerNames: Sequence[str], Tags: Sequence[TagTypeDef]
     ) -> Dict[str, Any]:
         """
         Adds the specified tags to the specified load balancer.
@@ -147,8 +147,16 @@ class ElasticLoadBalancingClient(BaseClient):
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#can_paginate)
         """
 
+    def close(self) -> None:
+        """
+        Closes underlying endpoint connections.
+
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.close)
+        [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#close)
+        """
+
     def configure_health_check(
-        self, *, LoadBalancerName: str, HealthCheck: "HealthCheckTypeDef"
+        self, *, LoadBalancerName: str, HealthCheck: HealthCheckTypeDef
     ) -> ConfigureHealthCheckOutputTypeDef:
         """
         Specifies the health check settings to use when evaluating the health state of
@@ -184,12 +192,12 @@ class ElasticLoadBalancingClient(BaseClient):
         self,
         *,
         LoadBalancerName: str,
-        Listeners: Sequence["ListenerTypeDef"],
+        Listeners: Sequence[ListenerTypeDef],
         AvailabilityZones: Sequence[str] = ...,
         Subnets: Sequence[str] = ...,
         SecurityGroups: Sequence[str] = ...,
         Scheme: str = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence[TagTypeDef] = ...
     ) -> CreateAccessPointOutputTypeDef:
         """
         Creates a Classic Load Balancer.
@@ -199,7 +207,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
 
     def create_load_balancer_listeners(
-        self, *, LoadBalancerName: str, Listeners: Sequence["ListenerTypeDef"]
+        self, *, LoadBalancerName: str, Listeners: Sequence[ListenerTypeDef]
     ) -> Dict[str, Any]:
         """
         Creates one or more listeners for the specified load balancer.
@@ -214,7 +222,7 @@ class ElasticLoadBalancingClient(BaseClient):
         LoadBalancerName: str,
         PolicyName: str,
         PolicyTypeName: str,
-        PolicyAttributes: Sequence["PolicyAttributeTypeDef"] = ...
+        PolicyAttributes: Sequence[PolicyAttributeTypeDef] = ...
     ) -> Dict[str, Any]:
         """
         Creates a policy with the specified attributes for the specified load balancer.
@@ -252,7 +260,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
 
     def deregister_instances_from_load_balancer(
-        self, *, LoadBalancerName: str, Instances: Sequence["InstanceTypeDef"]
+        self, *, LoadBalancerName: str, Instances: Sequence[InstanceTypeDef]
     ) -> DeregisterEndPointsOutputTypeDef:
         """
         Deregisters the specified instances from the specified load balancer.
@@ -273,7 +281,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
 
     def describe_instance_health(
-        self, *, LoadBalancerName: str, Instances: Sequence["InstanceTypeDef"] = ...
+        self, *, LoadBalancerName: str, Instances: Sequence[InstanceTypeDef] = ...
     ) -> DescribeEndPointStateOutputTypeDef:
         """
         Describes the state of the specified instances with respect to the specified
@@ -380,7 +388,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
 
     def modify_load_balancer_attributes(
-        self, *, LoadBalancerName: str, LoadBalancerAttributes: "LoadBalancerAttributesTypeDef"
+        self, *, LoadBalancerName: str, LoadBalancerAttributes: LoadBalancerAttributesTypeDef
     ) -> ModifyLoadBalancerAttributesOutputTypeDef:
         """
         Modifies the attributes of the specified load balancer.
@@ -390,7 +398,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
 
     def register_instances_with_load_balancer(
-        self, *, LoadBalancerName: str, Instances: Sequence["InstanceTypeDef"]
+        self, *, LoadBalancerName: str, Instances: Sequence[InstanceTypeDef]
     ) -> RegisterEndPointsOutputTypeDef:
         """
         Adds the specified instances to the specified load balancer.
@@ -400,7 +408,7 @@ class ElasticLoadBalancingClient(BaseClient):
         """
 
     def remove_tags(
-        self, *, LoadBalancerNames: Sequence[str], Tags: Sequence["TagKeyOnlyTypeDef"]
+        self, *, LoadBalancerNames: Sequence[str], Tags: Sequence[TagKeyOnlyTypeDef]
     ) -> Dict[str, Any]:
         """
         Removes one or more tags from the specified load balancer.
