@@ -24,84 +24,84 @@ else:
 __all__ = (
     "AccessLogTypeDef",
     "AddAvailabilityZonesInputRequestTypeDef",
-    "AddAvailabilityZonesOutputTypeDef",
-    "AddTagsInputRequestTypeDef",
+    "ResponseMetadataTypeDef",
+    "TagTypeDef",
     "AdditionalAttributeTypeDef",
     "AppCookieStickinessPolicyTypeDef",
     "ApplySecurityGroupsToLoadBalancerInputRequestTypeDef",
-    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
     "AttachLoadBalancerToSubnetsInputRequestTypeDef",
-    "AttachLoadBalancerToSubnetsOutputTypeDef",
     "BackendServerDescriptionTypeDef",
-    "ConfigureHealthCheckInputRequestTypeDef",
-    "ConfigureHealthCheckOutputTypeDef",
+    "HealthCheckTypeDef",
     "ConnectionDrainingTypeDef",
     "ConnectionSettingsTypeDef",
-    "CreateAccessPointInputRequestTypeDef",
-    "CreateAccessPointOutputTypeDef",
+    "ListenerTypeDef",
     "CreateAppCookieStickinessPolicyInputRequestTypeDef",
     "CreateLBCookieStickinessPolicyInputRequestTypeDef",
-    "CreateLoadBalancerListenerInputRequestTypeDef",
-    "CreateLoadBalancerPolicyInputRequestTypeDef",
+    "PolicyAttributeTypeDef",
     "CrossZoneLoadBalancingTypeDef",
     "DeleteAccessPointInputRequestTypeDef",
     "DeleteLoadBalancerListenerInputRequestTypeDef",
     "DeleteLoadBalancerPolicyInputRequestTypeDef",
+    "InstanceTypeDef",
+    "PaginatorConfigTypeDef",
+    "DescribeAccessPointsInputRequestTypeDef",
+    "DescribeAccountLimitsInputRequestTypeDef",
+    "LimitTypeDef",
+    "WaiterConfigTypeDef",
+    "InstanceStateTypeDef",
+    "DescribeLoadBalancerAttributesInputRequestTypeDef",
+    "DescribeLoadBalancerPoliciesInputRequestTypeDef",
+    "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
+    "DescribeTagsInputRequestTypeDef",
+    "DetachLoadBalancerFromSubnetsInputRequestTypeDef",
+    "LBCookieStickinessPolicyTypeDef",
+    "SourceSecurityGroupTypeDef",
+    "PolicyAttributeDescriptionTypeDef",
+    "PolicyAttributeTypeDescriptionTypeDef",
+    "RemoveAvailabilityZonesInputRequestTypeDef",
+    "TagKeyOnlyTypeDef",
+    "SetLoadBalancerListenerSSLCertificateInputRequestTypeDef",
+    "SetLoadBalancerPoliciesForBackendServerInputRequestTypeDef",
+    "SetLoadBalancerPoliciesOfListenerInputRequestTypeDef",
+    "AddAvailabilityZonesOutputTypeDef",
+    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
+    "AttachLoadBalancerToSubnetsOutputTypeDef",
+    "CreateAccessPointOutputTypeDef",
+    "DetachLoadBalancerFromSubnetsOutputTypeDef",
+    "RemoveAvailabilityZonesOutputTypeDef",
+    "AddTagsInputRequestTypeDef",
+    "TagDescriptionTypeDef",
+    "ConfigureHealthCheckInputRequestTypeDef",
+    "ConfigureHealthCheckOutputTypeDef",
+    "CreateAccessPointInputRequestTypeDef",
+    "CreateLoadBalancerListenerInputRequestTypeDef",
+    "ListenerDescriptionTypeDef",
+    "CreateLoadBalancerPolicyInputRequestTypeDef",
+    "LoadBalancerAttributesTypeDef",
     "DeregisterEndPointsInputRequestTypeDef",
     "DeregisterEndPointsOutputTypeDef",
+    "DescribeEndPointStateInputRequestTypeDef",
+    "RegisterEndPointsInputRequestTypeDef",
+    "RegisterEndPointsOutputTypeDef",
     "DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef",
-    "DescribeAccessPointsInputRequestTypeDef",
-    "DescribeAccessPointsOutputTypeDef",
     "DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef",
-    "DescribeAccountLimitsInputRequestTypeDef",
     "DescribeAccountLimitsOutputTypeDef",
     "DescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
     "DescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
     "DescribeEndPointStateInputInstanceInServiceWaitTypeDef",
-    "DescribeEndPointStateInputRequestTypeDef",
     "DescribeEndPointStateOutputTypeDef",
-    "DescribeLoadBalancerAttributesInputRequestTypeDef",
-    "DescribeLoadBalancerAttributesOutputTypeDef",
-    "DescribeLoadBalancerPoliciesInputRequestTypeDef",
-    "DescribeLoadBalancerPoliciesOutputTypeDef",
-    "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
-    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
-    "DescribeTagsInputRequestTypeDef",
-    "DescribeTagsOutputTypeDef",
-    "DetachLoadBalancerFromSubnetsInputRequestTypeDef",
-    "DetachLoadBalancerFromSubnetsOutputTypeDef",
-    "HealthCheckTypeDef",
-    "InstanceStateTypeDef",
-    "InstanceTypeDef",
-    "LBCookieStickinessPolicyTypeDef",
-    "LimitTypeDef",
-    "ListenerDescriptionTypeDef",
-    "ListenerTypeDef",
-    "LoadBalancerAttributesTypeDef",
-    "LoadBalancerDescriptionTypeDef",
-    "ModifyLoadBalancerAttributesInputRequestTypeDef",
-    "ModifyLoadBalancerAttributesOutputTypeDef",
-    "PaginatorConfigTypeDef",
     "PoliciesTypeDef",
-    "PolicyAttributeDescriptionTypeDef",
-    "PolicyAttributeTypeDef",
-    "PolicyAttributeTypeDescriptionTypeDef",
     "PolicyDescriptionTypeDef",
     "PolicyTypeDescriptionTypeDef",
-    "RegisterEndPointsInputRequestTypeDef",
-    "RegisterEndPointsOutputTypeDef",
-    "RemoveAvailabilityZonesInputRequestTypeDef",
-    "RemoveAvailabilityZonesOutputTypeDef",
     "RemoveTagsInputRequestTypeDef",
-    "ResponseMetadataTypeDef",
-    "SetLoadBalancerListenerSSLCertificateInputRequestTypeDef",
-    "SetLoadBalancerPoliciesForBackendServerInputRequestTypeDef",
-    "SetLoadBalancerPoliciesOfListenerInputRequestTypeDef",
-    "SourceSecurityGroupTypeDef",
-    "TagDescriptionTypeDef",
-    "TagKeyOnlyTypeDef",
-    "TagTypeDef",
-    "WaiterConfigTypeDef",
+    "DescribeTagsOutputTypeDef",
+    "DescribeLoadBalancerAttributesOutputTypeDef",
+    "ModifyLoadBalancerAttributesInputRequestTypeDef",
+    "ModifyLoadBalancerAttributesOutputTypeDef",
+    "LoadBalancerDescriptionTypeDef",
+    "DescribeLoadBalancerPoliciesOutputTypeDef",
+    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
+    "DescribeAccessPointsOutputTypeDef",
 )
 
 _RequiredAccessLogTypeDef = TypedDict(
@@ -133,21 +133,35 @@ AddAvailabilityZonesInputRequestTypeDef = TypedDict(
     },
 )
 
-AddAvailabilityZonesOutputTypeDef = TypedDict(
-    "AddAvailabilityZonesOutputTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "AvailabilityZones": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
-AddTagsInputRequestTypeDef = TypedDict(
-    "AddTagsInputRequestTypeDef",
+_RequiredTagTypeDef = TypedDict(
+    "_RequiredTagTypeDef",
     {
-        "LoadBalancerNames": Sequence[str],
-        "Tags": Sequence["TagTypeDef"],
+        "Key": str,
     },
 )
+_OptionalTagTypeDef = TypedDict(
+    "_OptionalTagTypeDef",
+    {
+        "Value": str,
+    },
+    total=False,
+)
+
+
+class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+    pass
+
 
 AdditionalAttributeTypeDef = TypedDict(
     "AdditionalAttributeTypeDef",
@@ -175,14 +189,6 @@ ApplySecurityGroupsToLoadBalancerInputRequestTypeDef = TypedDict(
     },
 )
 
-ApplySecurityGroupsToLoadBalancerOutputTypeDef = TypedDict(
-    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
-    {
-        "SecurityGroups": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 AttachLoadBalancerToSubnetsInputRequestTypeDef = TypedDict(
     "AttachLoadBalancerToSubnetsInputRequestTypeDef",
     {
@@ -191,14 +197,6 @@ AttachLoadBalancerToSubnetsInputRequestTypeDef = TypedDict(
     },
 )
 
-AttachLoadBalancerToSubnetsOutputTypeDef = TypedDict(
-    "AttachLoadBalancerToSubnetsOutputTypeDef",
-    {
-        "Subnets": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 BackendServerDescriptionTypeDef = TypedDict(
     "BackendServerDescriptionTypeDef",
     {
@@ -208,19 +206,14 @@ BackendServerDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-ConfigureHealthCheckInputRequestTypeDef = TypedDict(
-    "ConfigureHealthCheckInputRequestTypeDef",
+HealthCheckTypeDef = TypedDict(
+    "HealthCheckTypeDef",
     {
-        "LoadBalancerName": str,
-        "HealthCheck": "HealthCheckTypeDef",
-    },
-)
-
-ConfigureHealthCheckOutputTypeDef = TypedDict(
-    "ConfigureHealthCheckOutputTypeDef",
-    {
-        "HealthCheck": "HealthCheckTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Target": str,
+        "Interval": int,
+        "Timeout": int,
+        "UnhealthyThreshold": int,
+        "HealthyThreshold": int,
     },
 )
 
@@ -252,40 +245,28 @@ ConnectionSettingsTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateAccessPointInputRequestTypeDef = TypedDict(
-    "_RequiredCreateAccessPointInputRequestTypeDef",
+_RequiredListenerTypeDef = TypedDict(
+    "_RequiredListenerTypeDef",
     {
-        "LoadBalancerName": str,
-        "Listeners": Sequence["ListenerTypeDef"],
+        "Protocol": str,
+        "LoadBalancerPort": int,
+        "InstancePort": int,
     },
 )
-_OptionalCreateAccessPointInputRequestTypeDef = TypedDict(
-    "_OptionalCreateAccessPointInputRequestTypeDef",
+_OptionalListenerTypeDef = TypedDict(
+    "_OptionalListenerTypeDef",
     {
-        "AvailabilityZones": Sequence[str],
-        "Subnets": Sequence[str],
-        "SecurityGroups": Sequence[str],
-        "Scheme": str,
-        "Tags": Sequence["TagTypeDef"],
+        "InstanceProtocol": str,
+        "SSLCertificateId": str,
     },
     total=False,
 )
 
 
-class CreateAccessPointInputRequestTypeDef(
-    _RequiredCreateAccessPointInputRequestTypeDef, _OptionalCreateAccessPointInputRequestTypeDef
-):
+class ListenerTypeDef(_RequiredListenerTypeDef, _OptionalListenerTypeDef):
     pass
 
 
-CreateAccessPointOutputTypeDef = TypedDict(
-    "CreateAccessPointOutputTypeDef",
-    {
-        "DNSName": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 CreateAppCookieStickinessPolicyInputRequestTypeDef = TypedDict(
     "CreateAppCookieStickinessPolicyInputRequestTypeDef",
     {
@@ -318,38 +299,15 @@ class CreateLBCookieStickinessPolicyInputRequestTypeDef(
     pass
 
 
-CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
-    "CreateLoadBalancerListenerInputRequestTypeDef",
+PolicyAttributeTypeDef = TypedDict(
+    "PolicyAttributeTypeDef",
     {
-        "LoadBalancerName": str,
-        "Listeners": Sequence["ListenerTypeDef"],
-    },
-)
-
-_RequiredCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
-    "_RequiredCreateLoadBalancerPolicyInputRequestTypeDef",
-    {
-        "LoadBalancerName": str,
-        "PolicyName": str,
-        "PolicyTypeName": str,
-    },
-)
-_OptionalCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
-    "_OptionalCreateLoadBalancerPolicyInputRequestTypeDef",
-    {
-        "PolicyAttributes": Sequence["PolicyAttributeTypeDef"],
+        "AttributeName": str,
+        "AttributeValue": str,
     },
     total=False,
 )
 
-
-class CreateLoadBalancerPolicyInputRequestTypeDef(
-    _RequiredCreateLoadBalancerPolicyInputRequestTypeDef,
-    _OptionalCreateLoadBalancerPolicyInputRequestTypeDef,
-):
-    pass
-
-
 CrossZoneLoadBalancingTypeDef = TypedDict(
     "CrossZoneLoadBalancingTypeDef",
     {
@@ -380,27 +338,20 @@ DeleteLoadBalancerPolicyInputRequestTypeDef = TypedDict(
     },
 )
 
-DeregisterEndPointsInputRequestTypeDef = TypedDict(
-    "DeregisterEndPointsInputRequestTypeDef",
+InstanceTypeDef = TypedDict(
+    "InstanceTypeDef",
     {
-        "LoadBalancerName": str,
-        "Instances": Sequence["InstanceTypeDef"],
+        "InstanceId": str,
     },
+    total=False,
 )
 
-DeregisterEndPointsOutputTypeDef = TypedDict(
-    "DeregisterEndPointsOutputTypeDef",
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
     {
-        "Instances": List["InstanceTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef = TypedDict(
-    "DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef",
-    {
-        "LoadBalancerNames": Sequence[str],
-        "PaginationConfig": "PaginatorConfigTypeDef",
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
     },
     total=False,
 )
@@ -415,23 +366,6 @@ DescribeAccessPointsInputRequestTypeDef = TypedDict(
     total=False,
 )
 
-DescribeAccessPointsOutputTypeDef = TypedDict(
-    "DescribeAccessPointsOutputTypeDef",
-    {
-        "LoadBalancerDescriptions": List["LoadBalancerDescriptionTypeDef"],
-        "NextMarker": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef = TypedDict(
-    "DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef",
-    {
-        "PaginationConfig": "PaginatorConfigTypeDef",
-    },
-    total=False,
-)
-
 DescribeAccountLimitsInputRequestTypeDef = TypedDict(
     "DescribeAccountLimitsInputRequestTypeDef",
     {
@@ -441,232 +375,6 @@ DescribeAccountLimitsInputRequestTypeDef = TypedDict(
     total=False,
 )
 
-DescribeAccountLimitsOutputTypeDef = TypedDict(
-    "DescribeAccountLimitsOutputTypeDef",
-    {
-        "Limits": List["LimitTypeDef"],
-        "NextMarker": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef = TypedDict(
-    "_RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
-    {
-        "LoadBalancerName": str,
-    },
-)
-_OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef = TypedDict(
-    "_OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
-    {
-        "Instances": Sequence["InstanceTypeDef"],
-        "WaiterConfig": "WaiterConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class DescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef(
-    _RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef,
-    _OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef,
-):
-    pass
-
-
-_RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef = TypedDict(
-    "_RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
-    {
-        "LoadBalancerName": str,
-    },
-)
-_OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef = TypedDict(
-    "_OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
-    {
-        "Instances": Sequence["InstanceTypeDef"],
-        "WaiterConfig": "WaiterConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class DescribeEndPointStateInputInstanceDeregisteredWaitTypeDef(
-    _RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef,
-    _OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef,
-):
-    pass
-
-
-_RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef = TypedDict(
-    "_RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef",
-    {
-        "LoadBalancerName": str,
-    },
-)
-_OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef = TypedDict(
-    "_OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef",
-    {
-        "Instances": Sequence["InstanceTypeDef"],
-        "WaiterConfig": "WaiterConfigTypeDef",
-    },
-    total=False,
-)
-
-
-class DescribeEndPointStateInputInstanceInServiceWaitTypeDef(
-    _RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef,
-    _OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef,
-):
-    pass
-
-
-_RequiredDescribeEndPointStateInputRequestTypeDef = TypedDict(
-    "_RequiredDescribeEndPointStateInputRequestTypeDef",
-    {
-        "LoadBalancerName": str,
-    },
-)
-_OptionalDescribeEndPointStateInputRequestTypeDef = TypedDict(
-    "_OptionalDescribeEndPointStateInputRequestTypeDef",
-    {
-        "Instances": Sequence["InstanceTypeDef"],
-    },
-    total=False,
-)
-
-
-class DescribeEndPointStateInputRequestTypeDef(
-    _RequiredDescribeEndPointStateInputRequestTypeDef,
-    _OptionalDescribeEndPointStateInputRequestTypeDef,
-):
-    pass
-
-
-DescribeEndPointStateOutputTypeDef = TypedDict(
-    "DescribeEndPointStateOutputTypeDef",
-    {
-        "InstanceStates": List["InstanceStateTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeLoadBalancerAttributesInputRequestTypeDef = TypedDict(
-    "DescribeLoadBalancerAttributesInputRequestTypeDef",
-    {
-        "LoadBalancerName": str,
-    },
-)
-
-DescribeLoadBalancerAttributesOutputTypeDef = TypedDict(
-    "DescribeLoadBalancerAttributesOutputTypeDef",
-    {
-        "LoadBalancerAttributes": "LoadBalancerAttributesTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeLoadBalancerPoliciesInputRequestTypeDef = TypedDict(
-    "DescribeLoadBalancerPoliciesInputRequestTypeDef",
-    {
-        "LoadBalancerName": str,
-        "PolicyNames": Sequence[str],
-    },
-    total=False,
-)
-
-DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
-    "DescribeLoadBalancerPoliciesOutputTypeDef",
-    {
-        "PolicyDescriptions": List["PolicyDescriptionTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeLoadBalancerPolicyTypesInputRequestTypeDef = TypedDict(
-    "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
-    {
-        "PolicyTypeNames": Sequence[str],
-    },
-    total=False,
-)
-
-DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
-    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
-    {
-        "PolicyTypeDescriptions": List["PolicyTypeDescriptionTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DescribeTagsInputRequestTypeDef = TypedDict(
-    "DescribeTagsInputRequestTypeDef",
-    {
-        "LoadBalancerNames": Sequence[str],
-    },
-)
-
-DescribeTagsOutputTypeDef = TypedDict(
-    "DescribeTagsOutputTypeDef",
-    {
-        "TagDescriptions": List["TagDescriptionTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-DetachLoadBalancerFromSubnetsInputRequestTypeDef = TypedDict(
-    "DetachLoadBalancerFromSubnetsInputRequestTypeDef",
-    {
-        "LoadBalancerName": str,
-        "Subnets": Sequence[str],
-    },
-)
-
-DetachLoadBalancerFromSubnetsOutputTypeDef = TypedDict(
-    "DetachLoadBalancerFromSubnetsOutputTypeDef",
-    {
-        "Subnets": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-HealthCheckTypeDef = TypedDict(
-    "HealthCheckTypeDef",
-    {
-        "Target": str,
-        "Interval": int,
-        "Timeout": int,
-        "UnhealthyThreshold": int,
-        "HealthyThreshold": int,
-    },
-)
-
-InstanceStateTypeDef = TypedDict(
-    "InstanceStateTypeDef",
-    {
-        "InstanceId": str,
-        "State": str,
-        "ReasonCode": str,
-        "Description": str,
-    },
-    total=False,
-)
-
-InstanceTypeDef = TypedDict(
-    "InstanceTypeDef",
-    {
-        "InstanceId": str,
-    },
-    total=False,
-)
-
-LBCookieStickinessPolicyTypeDef = TypedDict(
-    "LBCookieStickinessPolicyTypeDef",
-    {
-        "PolicyName": str,
-        "CookieExpirationPeriod": int,
-    },
-    total=False,
-)
-
 LimitTypeDef = TypedDict(
     "LimitTypeDef",
     {
@@ -676,105 +384,79 @@ LimitTypeDef = TypedDict(
     total=False,
 )
 
-ListenerDescriptionTypeDef = TypedDict(
-    "ListenerDescriptionTypeDef",
+WaiterConfigTypeDef = TypedDict(
+    "WaiterConfigTypeDef",
     {
-        "Listener": "ListenerTypeDef",
-        "PolicyNames": List[str],
+        "Delay": int,
+        "MaxAttempts": int,
     },
     total=False,
 )
 
-_RequiredListenerTypeDef = TypedDict(
-    "_RequiredListenerTypeDef",
+InstanceStateTypeDef = TypedDict(
+    "InstanceStateTypeDef",
     {
-        "Protocol": str,
-        "LoadBalancerPort": int,
-        "InstancePort": int,
-    },
-)
-_OptionalListenerTypeDef = TypedDict(
-    "_OptionalListenerTypeDef",
-    {
-        "InstanceProtocol": str,
-        "SSLCertificateId": str,
+        "InstanceId": str,
+        "State": str,
+        "ReasonCode": str,
+        "Description": str,
     },
     total=False,
 )
 
-
-class ListenerTypeDef(_RequiredListenerTypeDef, _OptionalListenerTypeDef):
-    pass
-
-
-LoadBalancerAttributesTypeDef = TypedDict(
-    "LoadBalancerAttributesTypeDef",
-    {
-        "CrossZoneLoadBalancing": "CrossZoneLoadBalancingTypeDef",
-        "AccessLog": "AccessLogTypeDef",
-        "ConnectionDraining": "ConnectionDrainingTypeDef",
-        "ConnectionSettings": "ConnectionSettingsTypeDef",
-        "AdditionalAttributes": List["AdditionalAttributeTypeDef"],
-    },
-    total=False,
-)
-
-LoadBalancerDescriptionTypeDef = TypedDict(
-    "LoadBalancerDescriptionTypeDef",
+DescribeLoadBalancerAttributesInputRequestTypeDef = TypedDict(
+    "DescribeLoadBalancerAttributesInputRequestTypeDef",
     {
         "LoadBalancerName": str,
-        "DNSName": str,
-        "CanonicalHostedZoneName": str,
-        "CanonicalHostedZoneNameID": str,
-        "ListenerDescriptions": List["ListenerDescriptionTypeDef"],
-        "Policies": "PoliciesTypeDef",
-        "BackendServerDescriptions": List["BackendServerDescriptionTypeDef"],
-        "AvailabilityZones": List[str],
-        "Subnets": List[str],
-        "VPCId": str,
-        "Instances": List["InstanceTypeDef"],
-        "HealthCheck": "HealthCheckTypeDef",
-        "SourceSecurityGroup": "SourceSecurityGroupTypeDef",
-        "SecurityGroups": List[str],
-        "CreatedTime": datetime,
-        "Scheme": str,
+    },
+)
+
+DescribeLoadBalancerPoliciesInputRequestTypeDef = TypedDict(
+    "DescribeLoadBalancerPoliciesInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+        "PolicyNames": Sequence[str],
     },
     total=False,
 )
 
-ModifyLoadBalancerAttributesInputRequestTypeDef = TypedDict(
-    "ModifyLoadBalancerAttributesInputRequestTypeDef",
+DescribeLoadBalancerPolicyTypesInputRequestTypeDef = TypedDict(
+    "DescribeLoadBalancerPolicyTypesInputRequestTypeDef",
     {
-        "LoadBalancerName": str,
-        "LoadBalancerAttributes": "LoadBalancerAttributesTypeDef",
-    },
-)
-
-ModifyLoadBalancerAttributesOutputTypeDef = TypedDict(
-    "ModifyLoadBalancerAttributesOutputTypeDef",
-    {
-        "LoadBalancerName": str,
-        "LoadBalancerAttributes": "LoadBalancerAttributesTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PaginatorConfigTypeDef = TypedDict(
-    "PaginatorConfigTypeDef",
-    {
-        "MaxItems": int,
-        "PageSize": int,
-        "StartingToken": str,
+        "PolicyTypeNames": Sequence[str],
     },
     total=False,
 )
 
-PoliciesTypeDef = TypedDict(
-    "PoliciesTypeDef",
+DescribeTagsInputRequestTypeDef = TypedDict(
+    "DescribeTagsInputRequestTypeDef",
     {
-        "AppCookieStickinessPolicies": List["AppCookieStickinessPolicyTypeDef"],
-        "LBCookieStickinessPolicies": List["LBCookieStickinessPolicyTypeDef"],
-        "OtherPolicies": List[str],
+        "LoadBalancerNames": Sequence[str],
+    },
+)
+
+DetachLoadBalancerFromSubnetsInputRequestTypeDef = TypedDict(
+    "DetachLoadBalancerFromSubnetsInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+        "Subnets": Sequence[str],
+    },
+)
+
+LBCookieStickinessPolicyTypeDef = TypedDict(
+    "LBCookieStickinessPolicyTypeDef",
+    {
+        "PolicyName": str,
+        "CookieExpirationPeriod": int,
+    },
+    total=False,
+)
+
+SourceSecurityGroupTypeDef = TypedDict(
+    "SourceSecurityGroupTypeDef",
+    {
+        "OwnerAlias": str,
+        "GroupName": str,
     },
     total=False,
 )
@@ -788,15 +470,6 @@ PolicyAttributeDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-PolicyAttributeTypeDef = TypedDict(
-    "PolicyAttributeTypeDef",
-    {
-        "AttributeName": str,
-        "AttributeValue": str,
-    },
-    total=False,
-)
-
 PolicyAttributeTypeDescriptionTypeDef = TypedDict(
     "PolicyAttributeTypeDescriptionTypeDef",
     {
@@ -809,42 +482,6 @@ PolicyAttributeTypeDescriptionTypeDef = TypedDict(
     total=False,
 )
 
-PolicyDescriptionTypeDef = TypedDict(
-    "PolicyDescriptionTypeDef",
-    {
-        "PolicyName": str,
-        "PolicyTypeName": str,
-        "PolicyAttributeDescriptions": List["PolicyAttributeDescriptionTypeDef"],
-    },
-    total=False,
-)
-
-PolicyTypeDescriptionTypeDef = TypedDict(
-    "PolicyTypeDescriptionTypeDef",
-    {
-        "PolicyTypeName": str,
-        "Description": str,
-        "PolicyAttributeTypeDescriptions": List["PolicyAttributeTypeDescriptionTypeDef"],
-    },
-    total=False,
-)
-
-RegisterEndPointsInputRequestTypeDef = TypedDict(
-    "RegisterEndPointsInputRequestTypeDef",
-    {
-        "LoadBalancerName": str,
-        "Instances": Sequence["InstanceTypeDef"],
-    },
-)
-
-RegisterEndPointsOutputTypeDef = TypedDict(
-    "RegisterEndPointsOutputTypeDef",
-    {
-        "Instances": List["InstanceTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 RemoveAvailabilityZonesInputRequestTypeDef = TypedDict(
     "RemoveAvailabilityZonesInputRequestTypeDef",
     {
@@ -853,31 +490,12 @@ RemoveAvailabilityZonesInputRequestTypeDef = TypedDict(
     },
 )
 
-RemoveAvailabilityZonesOutputTypeDef = TypedDict(
-    "RemoveAvailabilityZonesOutputTypeDef",
+TagKeyOnlyTypeDef = TypedDict(
+    "TagKeyOnlyTypeDef",
     {
-        "AvailabilityZones": List[str],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-RemoveTagsInputRequestTypeDef = TypedDict(
-    "RemoveTagsInputRequestTypeDef",
-    {
-        "LoadBalancerNames": Sequence[str],
-        "Tags": Sequence["TagKeyOnlyTypeDef"],
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "Key": str,
     },
+    total=False,
 )
 
 SetLoadBalancerListenerSSLCertificateInputRequestTypeDef = TypedDict(
@@ -907,56 +525,438 @@ SetLoadBalancerPoliciesOfListenerInputRequestTypeDef = TypedDict(
     },
 )
 
-SourceSecurityGroupTypeDef = TypedDict(
-    "SourceSecurityGroupTypeDef",
+AddAvailabilityZonesOutputTypeDef = TypedDict(
+    "AddAvailabilityZonesOutputTypeDef",
     {
-        "OwnerAlias": str,
-        "GroupName": str,
+        "AvailabilityZones": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ApplySecurityGroupsToLoadBalancerOutputTypeDef = TypedDict(
+    "ApplySecurityGroupsToLoadBalancerOutputTypeDef",
+    {
+        "SecurityGroups": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+AttachLoadBalancerToSubnetsOutputTypeDef = TypedDict(
+    "AttachLoadBalancerToSubnetsOutputTypeDef",
+    {
+        "Subnets": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateAccessPointOutputTypeDef = TypedDict(
+    "CreateAccessPointOutputTypeDef",
+    {
+        "DNSName": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DetachLoadBalancerFromSubnetsOutputTypeDef = TypedDict(
+    "DetachLoadBalancerFromSubnetsOutputTypeDef",
+    {
+        "Subnets": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RemoveAvailabilityZonesOutputTypeDef = TypedDict(
+    "RemoveAvailabilityZonesOutputTypeDef",
+    {
+        "AvailabilityZones": List[str],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+AddTagsInputRequestTypeDef = TypedDict(
+    "AddTagsInputRequestTypeDef",
+    {
+        "LoadBalancerNames": Sequence[str],
+        "Tags": Sequence[TagTypeDef],
     },
-    total=False,
 )
 
 TagDescriptionTypeDef = TypedDict(
     "TagDescriptionTypeDef",
     {
         "LoadBalancerName": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": List[TagTypeDef],
     },
     total=False,
 )
 
-TagKeyOnlyTypeDef = TypedDict(
-    "TagKeyOnlyTypeDef",
+ConfigureHealthCheckInputRequestTypeDef = TypedDict(
+    "ConfigureHealthCheckInputRequestTypeDef",
     {
-        "Key": str,
+        "LoadBalancerName": str,
+        "HealthCheck": HealthCheckTypeDef,
     },
-    total=False,
 )
 
-_RequiredTagTypeDef = TypedDict(
-    "_RequiredTagTypeDef",
+ConfigureHealthCheckOutputTypeDef = TypedDict(
+    "ConfigureHealthCheckOutputTypeDef",
     {
-        "Key": str,
+        "HealthCheck": HealthCheckTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
-_OptionalTagTypeDef = TypedDict(
-    "_OptionalTagTypeDef",
+
+_RequiredCreateAccessPointInputRequestTypeDef = TypedDict(
+    "_RequiredCreateAccessPointInputRequestTypeDef",
     {
-        "Value": str,
+        "LoadBalancerName": str,
+        "Listeners": Sequence[ListenerTypeDef],
+    },
+)
+_OptionalCreateAccessPointInputRequestTypeDef = TypedDict(
+    "_OptionalCreateAccessPointInputRequestTypeDef",
+    {
+        "AvailabilityZones": Sequence[str],
+        "Subnets": Sequence[str],
+        "SecurityGroups": Sequence[str],
+        "Scheme": str,
+        "Tags": Sequence[TagTypeDef],
     },
     total=False,
 )
 
 
-class TagTypeDef(_RequiredTagTypeDef, _OptionalTagTypeDef):
+class CreateAccessPointInputRequestTypeDef(
+    _RequiredCreateAccessPointInputRequestTypeDef, _OptionalCreateAccessPointInputRequestTypeDef
+):
     pass
 
 
-WaiterConfigTypeDef = TypedDict(
-    "WaiterConfigTypeDef",
+CreateLoadBalancerListenerInputRequestTypeDef = TypedDict(
+    "CreateLoadBalancerListenerInputRequestTypeDef",
     {
-        "Delay": int,
-        "MaxAttempts": int,
+        "LoadBalancerName": str,
+        "Listeners": Sequence[ListenerTypeDef],
+    },
+)
+
+ListenerDescriptionTypeDef = TypedDict(
+    "ListenerDescriptionTypeDef",
+    {
+        "Listener": ListenerTypeDef,
+        "PolicyNames": List[str],
     },
     total=False,
 )
+
+_RequiredCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "_RequiredCreateLoadBalancerPolicyInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+        "PolicyName": str,
+        "PolicyTypeName": str,
+    },
+)
+_OptionalCreateLoadBalancerPolicyInputRequestTypeDef = TypedDict(
+    "_OptionalCreateLoadBalancerPolicyInputRequestTypeDef",
+    {
+        "PolicyAttributes": Sequence[PolicyAttributeTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateLoadBalancerPolicyInputRequestTypeDef(
+    _RequiredCreateLoadBalancerPolicyInputRequestTypeDef,
+    _OptionalCreateLoadBalancerPolicyInputRequestTypeDef,
+):
+    pass
+
+
+LoadBalancerAttributesTypeDef = TypedDict(
+    "LoadBalancerAttributesTypeDef",
+    {
+        "CrossZoneLoadBalancing": CrossZoneLoadBalancingTypeDef,
+        "AccessLog": AccessLogTypeDef,
+        "ConnectionDraining": ConnectionDrainingTypeDef,
+        "ConnectionSettings": ConnectionSettingsTypeDef,
+        "AdditionalAttributes": List[AdditionalAttributeTypeDef],
+    },
+    total=False,
+)
+
+DeregisterEndPointsInputRequestTypeDef = TypedDict(
+    "DeregisterEndPointsInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+        "Instances": Sequence[InstanceTypeDef],
+    },
+)
+
+DeregisterEndPointsOutputTypeDef = TypedDict(
+    "DeregisterEndPointsOutputTypeDef",
+    {
+        "Instances": List[InstanceTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredDescribeEndPointStateInputRequestTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+    },
+)
+_OptionalDescribeEndPointStateInputRequestTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputRequestTypeDef",
+    {
+        "Instances": Sequence[InstanceTypeDef],
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputRequestTypeDef(
+    _RequiredDescribeEndPointStateInputRequestTypeDef,
+    _OptionalDescribeEndPointStateInputRequestTypeDef,
+):
+    pass
+
+
+RegisterEndPointsInputRequestTypeDef = TypedDict(
+    "RegisterEndPointsInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+        "Instances": Sequence[InstanceTypeDef],
+    },
+)
+
+RegisterEndPointsOutputTypeDef = TypedDict(
+    "RegisterEndPointsOutputTypeDef",
+    {
+        "Instances": List[InstanceTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef = TypedDict(
+    "DescribeAccessPointsInputDescribeLoadBalancersPaginateTypeDef",
+    {
+        "LoadBalancerNames": Sequence[str],
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef = TypedDict(
+    "DescribeAccountLimitsInputDescribeAccountLimitsPaginateTypeDef",
+    {
+        "PaginationConfig": PaginatorConfigTypeDef,
+    },
+    total=False,
+)
+
+DescribeAccountLimitsOutputTypeDef = TypedDict(
+    "DescribeAccountLimitsOutputTypeDef",
+    {
+        "Limits": List[LimitTypeDef],
+        "NextMarker": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
+    {
+        "LoadBalancerName": str,
+    },
+)
+_OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef",
+    {
+        "Instances": Sequence[InstanceTypeDef],
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef(
+    _RequiredDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef,
+    _OptionalDescribeEndPointStateInputAnyInstanceInServiceWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
+    {
+        "LoadBalancerName": str,
+    },
+)
+_OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef",
+    {
+        "Instances": Sequence[InstanceTypeDef],
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputInstanceDeregisteredWaitTypeDef(
+    _RequiredDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef,
+    _OptionalDescribeEndPointStateInputInstanceDeregisteredWaitTypeDef,
+):
+    pass
+
+
+_RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef = TypedDict(
+    "_RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef",
+    {
+        "LoadBalancerName": str,
+    },
+)
+_OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef = TypedDict(
+    "_OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef",
+    {
+        "Instances": Sequence[InstanceTypeDef],
+        "WaiterConfig": WaiterConfigTypeDef,
+    },
+    total=False,
+)
+
+
+class DescribeEndPointStateInputInstanceInServiceWaitTypeDef(
+    _RequiredDescribeEndPointStateInputInstanceInServiceWaitTypeDef,
+    _OptionalDescribeEndPointStateInputInstanceInServiceWaitTypeDef,
+):
+    pass
+
+
+DescribeEndPointStateOutputTypeDef = TypedDict(
+    "DescribeEndPointStateOutputTypeDef",
+    {
+        "InstanceStates": List[InstanceStateTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PoliciesTypeDef = TypedDict(
+    "PoliciesTypeDef",
+    {
+        "AppCookieStickinessPolicies": List[AppCookieStickinessPolicyTypeDef],
+        "LBCookieStickinessPolicies": List[LBCookieStickinessPolicyTypeDef],
+        "OtherPolicies": List[str],
+    },
+    total=False,
+)
+
+PolicyDescriptionTypeDef = TypedDict(
+    "PolicyDescriptionTypeDef",
+    {
+        "PolicyName": str,
+        "PolicyTypeName": str,
+        "PolicyAttributeDescriptions": List[PolicyAttributeDescriptionTypeDef],
+    },
+    total=False,
+)
+
+PolicyTypeDescriptionTypeDef = TypedDict(
+    "PolicyTypeDescriptionTypeDef",
+    {
+        "PolicyTypeName": str,
+        "Description": str,
+        "PolicyAttributeTypeDescriptions": List[PolicyAttributeTypeDescriptionTypeDef],
+    },
+    total=False,
+)
+
+RemoveTagsInputRequestTypeDef = TypedDict(
+    "RemoveTagsInputRequestTypeDef",
+    {
+        "LoadBalancerNames": Sequence[str],
+        "Tags": Sequence[TagKeyOnlyTypeDef],
+    },
+)
+
+DescribeTagsOutputTypeDef = TypedDict(
+    "DescribeTagsOutputTypeDef",
+    {
+        "TagDescriptions": List[TagDescriptionTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeLoadBalancerAttributesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerAttributesOutputTypeDef",
+    {
+        "LoadBalancerAttributes": LoadBalancerAttributesTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ModifyLoadBalancerAttributesInputRequestTypeDef = TypedDict(
+    "ModifyLoadBalancerAttributesInputRequestTypeDef",
+    {
+        "LoadBalancerName": str,
+        "LoadBalancerAttributes": LoadBalancerAttributesTypeDef,
+    },
+)
+
+ModifyLoadBalancerAttributesOutputTypeDef = TypedDict(
+    "ModifyLoadBalancerAttributesOutputTypeDef",
+    {
+        "LoadBalancerName": str,
+        "LoadBalancerAttributes": LoadBalancerAttributesTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+LoadBalancerDescriptionTypeDef = TypedDict(
+    "LoadBalancerDescriptionTypeDef",
+    {
+        "LoadBalancerName": str,
+        "DNSName": str,
+        "CanonicalHostedZoneName": str,
+        "CanonicalHostedZoneNameID": str,
+        "ListenerDescriptions": List[ListenerDescriptionTypeDef],
+        "Policies": PoliciesTypeDef,
+        "BackendServerDescriptions": List[BackendServerDescriptionTypeDef],
+        "AvailabilityZones": List[str],
+        "Subnets": List[str],
+        "VPCId": str,
+        "Instances": List[InstanceTypeDef],
+        "HealthCheck": HealthCheckTypeDef,
+        "SourceSecurityGroup": SourceSecurityGroupTypeDef,
+        "SecurityGroups": List[str],
+        "CreatedTime": datetime,
+        "Scheme": str,
+    },
+    total=False,
+)
+
+DescribeLoadBalancerPoliciesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerPoliciesOutputTypeDef",
+    {
+        "PolicyDescriptions": List[PolicyDescriptionTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeLoadBalancerPolicyTypesOutputTypeDef = TypedDict(
+    "DescribeLoadBalancerPolicyTypesOutputTypeDef",
+    {
+        "PolicyTypeDescriptions": List[PolicyTypeDescriptionTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAccessPointsOutputTypeDef = TypedDict(
+    "DescribeAccessPointsOutputTypeDef",
+    {
+        "LoadBalancerDescriptions": List[LoadBalancerDescriptionTypeDef],
+        "NextMarker": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
