@@ -25,14 +25,14 @@ Usage::
 """
 from typing import Sequence
 
-from botocore.waiter import Waiter as Boto3Waiter
+from botocore.waiter import Waiter
 
 from .type_defs import InstanceTypeDef, WaiterConfigTypeDef
 
 __all__ = ("AnyInstanceInServiceWaiter", "InstanceDeregisteredWaiter", "InstanceInServiceWaiter")
 
 
-class AnyInstanceInServiceWaiter(Boto3Waiter):
+class AnyInstanceInServiceWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#anyinstanceinservicewaiter)
@@ -42,8 +42,8 @@ class AnyInstanceInServiceWaiter(Boto3Waiter):
         self,
         *,
         LoadBalancerName: str,
-        Instances: Sequence["InstanceTypeDef"] = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        Instances: Sequence[InstanceTypeDef] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.AnyInstanceInService.wait)
@@ -51,7 +51,7 @@ class AnyInstanceInServiceWaiter(Boto3Waiter):
         """
 
 
-class InstanceDeregisteredWaiter(Boto3Waiter):
+class InstanceDeregisteredWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#instancederegisteredwaiter)
@@ -61,8 +61,8 @@ class InstanceDeregisteredWaiter(Boto3Waiter):
         self,
         *,
         LoadBalancerName: str,
-        Instances: Sequence["InstanceTypeDef"] = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        Instances: Sequence[InstanceTypeDef] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceDeregistered.wait)
@@ -70,7 +70,7 @@ class InstanceDeregisteredWaiter(Boto3Waiter):
         """
 
 
-class InstanceInServiceWaiter(Boto3Waiter):
+class InstanceInServiceWaiter(Waiter):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService)
     [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_elb/waiters/#instanceinservicewaiter)
@@ -80,8 +80,8 @@ class InstanceInServiceWaiter(Boto3Waiter):
         self,
         *,
         LoadBalancerName: str,
-        Instances: Sequence["InstanceTypeDef"] = ...,
-        WaiterConfig: "WaiterConfigTypeDef" = ...
+        Instances: Sequence[InstanceTypeDef] = ...,
+        WaiterConfig: WaiterConfigTypeDef = ...
     ) -> None:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Waiter.InstanceInService.wait)
